
Add `{% meld_scripts %}` to templates/base.html


Create a component in meld/components
person.py

Create the component view in templates/meld
templates/meld/person.html

Use `{% meld 'component_name' %}` to use your component in the template



